Councilmatic
====================

Reusable Django app providing the core functions for Councilmatic

Team
----

-  David Moore - project manager
-  Forest Gregg - Open Civic Data (OCD) and Legistar scraping
-  Cathy Deng - data models and loading
-  Derek Eder - front end
-  Eric van Zanten - search and dev ops

Errors / Bugs
-------------

If something is not behaving intuitively, it is a bug, and should be
reported. Report it here:
https://github.com/datamade/chi-councilmatic/issues

Note on Patches/Pull Requests
-----------------------------

-  Fork the project.
-  Make your feature addition or bug fix.
-  Commit, do not mess with rakefile, version, or history.
-  Send a pull request. Bonus points for topic branches.

Copyright
---------

Copyright (c) 2015 Participatory Politics Foundation and DataMade.
Released under the `MIT
License <https://github.com/datamade/chi-councilmatic/blob/master/LICENSE>`__.
